﻿---------------------------------------------------------------------------------------------------------
-- @Author: Mantrid -------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------------------------
----- Please ask permission before using this, or part of this, script in your own project --------------
---------------------------------------------------------------------------------------------------------

EngineStarter = {}

EngineStarter.path = g_currentModDirectory;

local modDescFile = loadXMLFile("modDesc", EngineStarter.path .. "modDesc.xml");
EngineStarter.title = getXMLString(modDescFile, "modDesc.title.en");
EngineStarter.author = getXMLString(modDescFile, "modDesc.author");
EngineStarter.version = getXMLString(modDescFile, "modDesc.version");
delete(modDescFile);

print("Info: Loaded mod "..EngineStarter.title.." v"..EngineStarter.version.." by "..EngineStarter.author);

local EngineStarter_mt = Class(EngineStarter)

function EngineStarter:new()
	local self = setmetatable({}, EngineStarter_mt)

	-- Appended functions don't have access to self, so override instead, but act like appended
	Motorized.onLoad = Utils.overwrittenFunction(Motorized.onLoad, self.Motorized_insteadOf_onLoad)
	Motorized.onUpdate = Utils.overwrittenFunction(Motorized.onUpdate, self.Motorized_insteadOf_onUpdate)
	Motorized.onDraw = Utils.overwrittenFunction(Motorized.onDraw, self.Motorized_insteadOf_onDraw)

	return self
end

function EngineStarter:Motorized_insteadOf_onLoad(superFunc, ...)
	-- Call the base function first
	superFunc(self, ...)

	-- Add our boolean
	self.spec_motorized.showMotorStartingWarning = false
end

function EngineStarter:Motorized_insteadOf_onUpdate(superFunc, ...)
	-- Call the base function first
	superFunc(self, ...)

	-- Gather what we need, like the base method does
	local spec = self.spec_motorized

	-- Read the input again, like the base method does
	local accInput = 0

	if self.getAxisForward ~= nil then
		accInput = self:getAxisForward()
	end

	-- Check the same condition the base method does,
	if not self:getIsMotorStarted() and self:getCanMotorRun() and accInput ~= 0 then
		spec.showTurnOnMotorWarning = false -- Undo default flag
		spec.showMotorStartingWarning = true -- Set our own flag
		
		self:startMotor(true) -- Start the engine
	end
end

function EngineStarter:Motorized_insteadOf_onDraw(superFunc, ...)
  -- Call the base function first
  superFunc(self, ...)

	-- Check if our flag is set
	if self.spec_motorized.showMotorStartingWarning then
		-- Display the warning, for the length of the motorStartDuration and then clear our flag
		g_currentMission:showBlinkingWarning(g_i18n:getText("engineStartNotification"), self.spec_motorized.motorStartDuration)
		self.spec_motorized.showMotorStartingWarning = false
	end
end
